@@ -2,19 +2,21 @@ context("simmap")
 
 
 ## Make a simmap tree 
-library(phytools)
-set.seed(10) 
-tree <- rbdtree(b = log(50), d = 0, Tmax = .5)
-Q <- matrix(c(-2, 1, 1, 1, -2 ,1 ,1, 1, -2), 3, 3) 
-rownames(Q) <- colnames(Q) <- c("A", "B", "C") 
-mtree <- sim.history(tree, Q) 
 
-cols <- c("red", "blue", "green")
-names(cols) <- rownames(Q)
 
 
 test_that("we can coerce an ape::phylo tree with a 
           phytools:simmap extension into nexml", {
+  skip_if_not_installed("phytools")
+  library("phytools")
+  set.seed(10) 
+  tree <- rbdtree(b = log(50), d = 0, Tmax = .5)
+  Q <- matrix(c(-2, 1, 1, 1, -2 ,1 ,1, 1, -2), 3, 3) 
+  rownames(Q) <- colnames(Q) <- c("A", "B", "C") 
+  mtree <- sim.history(tree, Q) 
+
+  cols <- c("red", "blue", "green")
+  names(cols) <- rownames(Q)
   nex <- simmap_to_nexml(mtree) 
   expect_is(nex, "nexml")
 
@@ -32,11 +34,4 @@ test_that("we can coerce an ape::phylo tree with a
 })
 
 
-test_that("we have the right state ids in the NeXML", {
-
-  
-})
-
-
-
 
